@@ -13,6 +13,7 @@
 #define QTM_MODEST_PLUGIN_SEND_EMAIL "SendEmail"
 #define MODESTENGINE_DEFAULT_ACCOUNT "/apps/modest/default_account"
 #define MODESTENGINE_ACCOUNT_EMAIL "/apps/modest/accounts/%s/email"
+
 void print_usage_and_exit(const char* arg_name)
 {
   printf("usage: %s [OPTION...] address \n", arg_name);
@@ -28,6 +29,7 @@ gchar* get_default_mail_account()
   gchar* default_email = NULL;
   GConfClient* gconfclient = gconf_client_get_default();
   gchar* default_account_id = gconf_client_get_string(gconfclient, MODESTENGINE_DEFAULT_ACCOUNT, &error);
+  printf("default_account_id %s\n", default_account_id);
   if(error)
   {
     printf("can not find default account\n");
@@ -37,13 +39,19 @@ gchar* get_default_mail_account()
   {
     gchar* account_key = gconf_escape_key(default_account_id, -1);
     gchar* default_email_key = g_strdup_printf(MODESTENGINE_ACCOUNT_EMAIL, account_key);
+    printf("account_key %s\n", account_key);
     g_free(account_key);
+    printf("default_email_key %s\n", default_email_key);
     default_email = gconf_client_get_string(gconfclient, default_email_key, &error);
+    printf("default_email %s\n", default_email);
     if(error || default_email == NULL)
     { 
-      fprintf(stderr, "can not get default email account (%s)\n", error->message);
-      g_error_free(error);
-      return NULL;
+      if(error)
+	fprintf(stderr, "can not get default email account (%s)\n", error->message);
+      else
+	fprintf(stderr, "no email entry for account (%s)\n", default_account_id);
+      if(error)
+	g_error_free(error);
     }
     g_free(default_email_key);
     g_free(default_account_id);
@@ -129,7 +137,7 @@ int main(int argc, char** argv)
   int c;
   static struct option long_options[] = {
     {"subject", 1, 0, 's'},
-    {"attachement", 0, 0, 'a'},
+    {"attachement", 1, 0, 'a'},
     {"help", 0, 0, 'h'},
     {0, 0, 0, 0}
   };
@@ -190,7 +198,6 @@ int main(int argc, char** argv)
     receiver = g_string_append(receiver, argv[optind]);
   }
   gchar* default_email = get_default_mail_account();
-
   GString* text = read_message_input();
   if(default_email)
   {
@@ -202,7 +209,7 @@ int main(int argc, char** argv)
   }
   else
   {
-    fprintf(stderr, "error no email\n");
+    fprintf(stderr, "error no email sent\n");
   }
   return 0;
 }
